@@ -5,7 +5,7 @@
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2023
-;; Version: 1.3
+;; Version: 1.4
 ;; Package-Requires: ((emacs "27.1") (compat "29.1.4.4"))
 ;; Homepage: https://github.com/minad/jinx
 ;; Keywords: convenience, text
@@ -92,14 +92,12 @@
                font-lock-string-face)
     ;; `yaml-mode' and `yaml-ts-mode' are text-modes,
     ;; while they should better be conf- or prog-modes.
-    (yaml-mode font-lock-comment-face
-               font-lock-string-face)
-    (yaml-ts-mode font-lock-comment-face
-                  font-lock-string-face))
+    (yaml-mode . conf-mode)
+    (yaml-ts-mode . conf-mode))
   "Alist of faces per major mode.
 These faces mark regions which should be included in spell
 checking."
-  :type '(alist :key-type symbol :value-type (repeat face)))
+  :type '(alist :key-type symbol :value-type (choice symbol (repeat face))))
 
 (defcustom jinx-camel-modes
   '(java-mode java-ts-mode js-mode js-ts-mode ruby-mode ruby-ts-mode rust-mode
@@ -147,7 +145,7 @@ Set to t to enable camelCase everywhere."
   "Alist of faces per major mode.
 These faces mark regions which should be excluded in spell
 checking."
-  :type '(alist :key-type symbol :value-type (repeat face)))
+  :type '(alist :key-type symbol :value-type (choice symbol (repeat face))))
 
 (defcustom jinx-exclude-regexps
   '((emacs-lisp-mode "Package-Requires:.*$")
@@ -159,7 +157,7 @@ checking."
        "\\(?:Local Variables\\|End\\):\\s-*$" ;; Local variable indicator
        "jinx-\\(?:languages\\|local-words\\):\\s-+.*$")) ;; Local variables
   "List of excluded regexps per major mode."
-  :type '(alist :key-type symbol :value-type (repeat regexp)))
+  :type '(alist :key-type symbol :value-type (choice symbol (repeat regexp))))
 
 (defcustom jinx-suggestion-distance 3
   "Maximal edit distance for session words to be included in suggestions."
@@ -529,7 +527,8 @@ If CHECK is non-nil, always check first."
 (defun jinx--mode-list (list)
   "Lookup by major mode in LIST."
   (cl-loop for (mode . vals) in list
-           if (or (eq mode t) (derived-mode-p mode)) append vals))
+           if (or (eq mode t) (derived-mode-p mode))
+           append (if (symbolp vals) (alist-get vals list) vals)))
 
 (defun jinx--get-org-language ()
   "Get language from Org #+language keyword."
@@ -779,7 +778,8 @@ Optionally show prompt INFO and insert INITIAL input."
            (len (length choice)))
       (pcase (and (> len 0) (assq (aref choice 0) jinx--save-keys))
         (`(,key . ,fun)
-         (funcall fun 'save key (if (> len 1) (substring choice 1) word))
+         (funcall fun 'save key
+                  (if (> len 1) (substring-no-properties choice 1) word))
          (jinx--recheck-overlays))
         ((guard (not (equal choice word)))
          (jinx--correct-replace overlay choice)))
@@ -929,9 +929,12 @@ buffers.  See also the variable `jinx-languages'."
   "Correct all misspelled words in the buffer."
   (interactive "*")
   (jinx--correct-guard
-   (let* ((overlays (jinx--force-overlays (point-min) (point-max) :check t))
+   (let* ((overlays (jinx--force-overlays (or (use-region-beginning) (point-min))
+                                          (or (use-region-end) (point-max))
+                                          :check t))
           (count (length overlays))
           (idx 0))
+     (deactivate-mark)
      (push-mark)
      (while-let ((ov (nth idx overlays)))
        (if-let (((overlay-buffer ov))
@@ -981,13 +984,14 @@ Optionally insert INITIAL input in the minibuffer."
 This command dispatches to the following commands:
   - `jinx-correct-nearest': If prefix ARG is nil, correct nearest
     misspelled word.
-  - `jinx-correct-all': If prefix ARG is 4, corresponding to
-    \\[universal-argument] pressed once, correct all misspelled words.
+  - `jinx-correct-all': If a region is marked, or if prefix ARG
+    is 4, corresponding to \\[universal-argument] pressed once,
+    correct all misspelled words.
   - `jinx-correct-word': If prefix ARG is 16, corresponding to
     \\[universal-argument] pressed twice, correct word before point."
   (interactive "*P")
   (pcase arg
-    ('nil (jinx-correct-nearest))
+    ('nil (if (use-region-p) (jinx-correct-all) (jinx-correct-nearest)))
     ('(16) (jinx-correct-word))
     (_ (jinx-correct-all))))
 
@@ -1033,7 +1037,7 @@ This command dispatches to the following commands:
       (jinx-mode -1)))
    (jinx-mode
     (jinx--load-module)
-    (let ((enable-local-variables :safe))
+    (let ((enable-local-variables :safe) (enable-local-eval nil))
       (hack-local-variables 'ignore-mode))
     (jinx--get-org-language)
     (setq jinx--exclude-regexp
